@@ -4,15 +4,15 @@ import sys
 from pudb import _get_debugger, set_interrupt_handler
 
 
-def __myimport__(name, *args, **kwargs):  # noqa: N802
-    if name == 'pudb.b':
+def __myimport__(name, *args, **kwargs):  # noqa: N807
+    if name == "pudb.b":
         set_trace()
     return __origimport__(name, *args, **kwargs)  # noqa: F821
 
 
 # Will only be run on first import
-__builtins__['__origimport__'] = __import__
-__builtins__['__import__'] = __myimport__
+__builtins__["__origimport__"] = __import__
+__builtins__["__import__"] = __myimport__
 
 
 def set_trace():
